Coverage for setup.py: 0%

1 import os

2

3 from setuptools import setup

4

5 print(

6 os.path.join(os.getcwd(), "requirements.txt"),

7 os.listdir(),

8 "requirements.txt" in os.listdir(),

9)

10

11 with open(os.path.join(os.getcwd(), "README.md"), "r", encoding="utf-8") as fh:

12 long_description = fh.read()

13

14# pip-compile requirements.in -> requirements.txt

15 with open(os.path.join(os.getcwd(), "requirements.txt")) as f:

16 required = f.read().splitlines()

17

18# pip-compile requirements-dev.in -> requirements-dev.txt

19 with open(os.path.join(os.getcwd(), "requirements-dev.txt")) as f:

20 dev_required = f.read().splitlines()

21

22 setup(

23 name="edwh-ghost",

24 version="0.1.10",

25 description="Python client for Ghost API v3/v4/v5",

26 url="https://github.com/educationwarehouse/edwh-ghost",

27 author="Education Warehouse",

28 author_email="remco.b@educationwarehouse.nl",

29 long_description=long_description,

30 long_description_content_type="text/markdown",

31 license="MIT",

32 packages=["ghost"],

33 zip_safe=False,

34 python_requires=">=3.7",

35 install_requires=required,

36 extras_require={"dev": dev_required},

37)